durtools.rational_to_equal_or_lesser_assignable_rational
========================================================

.. autofunction:: abjad.tools.durtools.rational_to_equal_or_lesser_assignable_rational
